@@ -1,17 +1,29 @@
 #' @importFrom grid grid.draw
 #' @importFrom rlang try_fetch cnd_signal
 #' @export
-print.alignpatches <- function(x, newpage = is.null(vp), vp = NULL, ...) {
+`print.ggalign::AlignPatches` <- function(x, newpage = is.null(vp),
+                                          vp = NULL, ...) {
     ggplot2::set_last_plot(x)
-    if (newpage) grid::grid.newpage()
+    if (newpage) {
+        grid::grid.newpage()
+        if (is.character(vp)) {
+            cli_abort(c(
+                "{.arg vp} cannot be a character string when {.arg newpage} is TRUE.",
+                i = "Please provide a viewport object or set {.arg newpage} to FALSE."
+            ))
+        }
+    }
     if (!is.null(vp)) {
         if (is.character(vp)) {
+            cur <- grid::current.viewport()$name
             grid::seekViewport(vp)
+            if (!identical(cur, "ROOT")) on.exit(grid::seekViewport(cur))
         } else {
             grid::pushViewport(vp)
+            on.exit(grid::upViewport())
         }
-        on.exit(grid::upViewport())
     }
+
     # render the plot
     try_fetch(
         grid.draw(x, ...),
@@ -39,28 +51,25 @@ print.alignpatches <- function(x, newpage = is.null(vp), vp = NULL, ...) {
 
 #' @importFrom grid grid.draw
 #' @exportS3Method
-grid.draw.alignpatches <- function(x, recording = TRUE) {
+`grid.draw.ggalign::AlignPatches` <- function(x, recording = TRUE) {
     grid.draw(ggalignGrob(x), recording = recording)
 }
 
 #' @export
-ggalign_build.alignpatches <- function(x) x
+`ggalign_build.ggalign::AlignPatches` <- function(x) x
 
-#' @importFrom ggplot2 find_panel element_render theme theme_get
+#' @importFrom ggplot2 find_panel element_render theme theme_get complete_theme
 #' @importFrom gtable gtable_add_grob gtable_add_rows gtable_add_cols
 #' @importFrom rlang arg_match0
+#' @importFrom S7 prop
 #' @export
-ggalign_gtable.alignpatches <- function(x) {
-    titles <- .subset2(x, "titles")
+`ggalign_gtable.ggalign::AlignPatches` <- function(x) {
+    table <- alignpatch(x)$patch_gtable()
+
+    titles <- prop(x, "titles")
 
     # ensure theme has no missing value
-    theme <- .subset2(x, "theme") %||% theme_get()
-
-    # `TO-DO`: use `complete_theme()` from ggplot2 release
-    theme <- complete_theme(theme)
-    x$theme <- theme
-    table <- alignpatch(x)$patch_gtable(top_level = TRUE)
-
+    theme <- complete_theme(prop(x, "theme") %||% theme_get())
     fix_respect <- is.matrix(.subset2(table, "respect"))
 
     # Add title, subtitle, and caption -------------------
