@@ -4,11 +4,12 @@
 #' following functions romove these restrictions:
 #' - `free_align`: if we want to compose plots without alignment of some panel
 #' axes (panel won't be aligned). we can wrap the plot with `free_align`.
-#' - `free_border`: If we want to compose plots without alignment of the panel
-#' borders (but still align the panels themselves), we can wrap the plot with
-#' `free_border`.
-#' - `free_lab`: If we want to compose plots without alignment of the axis
-#' title, we can wrap the plot with `free_lab`.
+#' - `free_border`: attaches borders (e.g., axis titles, tick marks) directly to
+#'   the plot panel. This keeps them visually close to the panel during
+#'   alignment.
+#' - `free_lab()`: Similar to `free_border()`, but only attaches axis titles
+#'   and tick labels, not full borders. It's mainly included for completeness;
+#'   in most cases, combining `free_border()` and `free_space()` is sufficient.
 #' - `free_space`: Removing the ggplot element sizes when aligning.
 #' - `free_vp`: Customize the [viewport][grid::viewport] when aligning.
 #' - `free_guide`: If we want to override the behaviour of the overall guides
@@ -93,7 +94,7 @@ free_align.ggplot <- function(plot, axes = "tlbr") {
 }
 
 #' @export
-free_align.alignpatches <- free_align.ggplot
+`free_align.ggalign::AlignPatches` <- free_align.ggplot
 
 #' @importFrom rlang is_empty
 #' @export
@@ -101,11 +102,11 @@ free_align.free_lab <- function(plot, axes = "tlbr") {
     assert_position(axes)
     # if axes are free, it's not necessary to free the labs
     free_labs <- setdiff_position(attr(plot, "free_labs"), axes)
-    if (is_empty(free_labs)) {
+    if (nzchar(free_labs)) {
+        attr(plot, "free_labs") <- free_labs
+    } else {
         attr(plot, "free_labs") <- NULL
         plot <- remove_class(plot, "free_lab")
-    } else {
-        attr(plot, "free_labs") <- free_labs
     }
     NextMethod()
 }
@@ -115,11 +116,11 @@ free_align.free_lab <- function(plot, axes = "tlbr") {
 free_align.free_space <- function(plot, axes = "tlbr") {
     assert_position(axes)
     free_spaces <- setdiff_position(attr(plot, "free_spaces"), axes)
-    if (is_empty(free_spaces)) {
+    if (nzchar(free_spaces)) {
+        attr(plot, "free_spaces") <- free_spaces
+    } else {
         attr(plot, "free_spaces") <- NULL
         plot <- remove_class(plot, "free_space")
-    } else {
-        attr(plot, "free_spaces") <- free_spaces
     }
     NextMethod()
 }
@@ -129,11 +130,11 @@ free_align.free_space <- function(plot, axes = "tlbr") {
 free_align.free_border <- function(plot, axes = "tlbr") {
     assert_position(axes)
     free_borders <- setdiff_position(attr(plot, "free_borders"), axes)
-    if (is_empty(free_borders)) {
+    if (nzchar(free_borders)) {
+        attr(plot, "free_borders") <- free_borders
+    } else {
         attr(plot, "free_borders") <- NULL
         plot <- remove_class(plot, "free_border")
-    } else {
-        attr(plot, "free_borders") <- free_borders
     }
     NextMethod()
 }
