@@ -40,11 +40,11 @@ patch_titles <- function(top = waiver(), left = waiver(), bottom = waiver(),
     )
 }
 
-#' @importFrom ggplot2 find_panel calc_element zeroGrob element_grob merge_element
+#' @importFrom ggplot2 find_panel zeroGrob
+#' @importFrom ggplot2 calc_element element_grob merge_element
 #' @importFrom rlang arg_match0
 #' @importFrom grid grobName
 setup_patch_titles <- function(table, patch_titles, theme) {
-    # complete_theme() will ensure `plot_title` exists
     old_text <- calc_element("plot.title", theme)
     # always justification by center for patch title
     old_text$hjust <- 0.5
@@ -171,11 +171,11 @@ setup_patch_titles <- function(table, patch_titles, theme) {
 
 #' @importFrom ggplot2 ggplot_add
 #' @export
-ggplot_add.ggalign_patch_labels <- function(object, plot, object_name) {
-    plot$ggalign_patch_labels <- update_non_waive(
-        .subset2(plot, "ggalign_patch_labels") %||% list(),
-        object
-    )
+ggplot_add.ggalign_patch_labels <- function(object, plot, object_name, ...) {
+    for (nm in names(object)) {
+        if (is.waive(.subset2(object, nm))) next
+        plot$ggalign_patch_labels[nm] <- list(.subset2(object, nm))
+    }
     if (!inherits(plot, "patch_ggplot")) {
         plot <- add_class(plot, "patch_ggplot")
     }
