@@ -78,7 +78,7 @@ make_wrap.ggplot <- function(patch, inset) {
 make_wrap.patch_ggplot <- make_wrapped_plot
 
 #' @export
-make_wrap.alignpatches <- make_wrapped_plot
+`make_wrap.ggalign::AlignPatches` <- make_wrapped_plot
 
 #################################################
 #' @importFrom ggplot2 ggproto ggproto_parent
@@ -89,9 +89,10 @@ alignpatch.wrapped_plot <- function(x) {
         "PatchWrapped", Parent,
         ggalign_wrapped_insets_under = x$ggalign_wrapped_insets_under,
         ggalign_wrapped_insets_above = x$ggalign_wrapped_insets_above,
-        patch_gtable = function(self, theme, guides, plot = Parent$plot) {
+        patch_gtable = function(self, theme = NULL, guides = NULL,
+                                tagger = NULL) {
             ans <- ggproto_parent(Parent, self)$patch_gtable(
-                theme = theme, guides = guides, plot = plot
+                theme = theme, guides = guides, tagger = tagger
             )
             ans <- add_wrapped_insets(
                 ans, self$ggalign_wrapped_insets_under, FALSE
