@@ -19,7 +19,7 @@ align_group <- function(group, active = NULL) {
     if (vec_size(group) == 0L) {
         cli_abort("{.arg group} cannot be empty")
     }
-    active <- update_active(active, new_active(use = FALSE))
+    active <- active_update(active(use = FALSE), active)
     align(
         align = AlignGroup,
         group = group,
@@ -32,8 +32,8 @@ align_group <- function(group, active = NULL) {
 AlignGroup <- ggproto("AlignGroup", CraftAlign,
     interact_layout = function(self, layout) {
         layout <- ggproto_parent(CraftAlign, self)$interact_layout(layout)
-        if (is.null(layout_nobs <- .subset2(layout@design, "nobs"))) {
-            layout@design["nobs"] <- list(vec_size(self$group))
+        if (is.na(layout_nobs <- prop(layout@domain, "nobs"))) {
+            prop(layout@domain, "nobs") <- vec_size(self$group)
         } else {
             assert_mismatch_nobs(
                 self, layout_nobs, vec_size(self$group),
