@@ -51,6 +51,10 @@ fortify_data_frame.character <- function(data, ..., data_arg = NULL,
     new_data_frame(ans)
 }
 
+#' @rdname fortify_data_frame.character
+#' @export
+fortify_data_frame.factor <- fortify_data_frame.character
+
 #' @rdname fortify_data_frame.character
 #' @export
 fortify_data_frame.numeric <- fortify_data_frame.character
@@ -74,6 +78,23 @@ fortify_data_frame.waiver <- function(data, ..., data_arg = NULL,
 #' @export
 fortify_data_frame.NULL <- fortify_data_frame.waiver
 
+#' @inherit fortify_data_frame.default title description
+#' @param data An object to be converted to a data frame.
+#' @inheritParams fortify_data_frame
+#' @return A data frame with at least following columns:
+#'
+#'   - `seqnames`: The sequence (e.g., chromosome) names.
+#'   - `start`: The start positions of the ranges.
+#'   - `end`: The end positions of the ranges.
+#'   - `width`: The width of each range.
+#'
+#' @family fortify_data_frame
+#' @export
+fortify_data_frame.GRanges <- function(data, ..., data_arg = NULL,
+                                       call = NULL) {
+    as.data.frame(data, ...)
+}
+
 #' @inherit fortify_data_frame.default title description
 #' @param data A matrix-like object.
 #' @param lvls A logical value indicating whether to restore factor levels using
@@ -107,7 +128,7 @@ fortify_data_frame.matrix <- function(data, lvls = NULL, ...,
     if (isFALSE(lvls)) {
         lvls <- NULL
     } else if (isTRUE(lvls)) {
-        lvls <- ggalign_lvls_get(lvls)
+        lvls <- ggalign_lvls_get(data)
     } else if (!is.null(lvls) && !is.character(lvls)) {
         cli_abort(
             "{.arg lvls} must be a single boolean value or a character",
