@@ -23,10 +23,8 @@
 #' [`unit()`][grid::unit]. Note that for [`circle_layout()`], all size values
 #' will be interpreted as relative sizes, as this layout type adjusts based on
 #' the available space in the circular arrangement.
-#' @param no_axes `r lifecycle::badge('experimental')` Logical; if `TRUE`,
-#'   removes axes elements for the alignment axis using [`theme_no_axes()`]. By
-#'   default, will use the option-
-#'   `r code_quote(sprintf("%s.align_no_axes", pkg_nm()))`.
+#' @param no_axes `r lifecycle::badge("deprecated")` Please add
+#' [`theme()`][ggplot2::theme] directly to the ggplot instead.
 #' @param active A [`active()`] object that defines the context settings when
 #'   added to a layout.
 #' @section ggplot2 specification:
@@ -85,17 +83,22 @@
 #' @importFrom rlang list2
 #' @export
 ggalign <- function(data = waiver(), mapping = aes(), ..., size = NULL,
-                    no_axes = NULL, active = NULL) {
+                    active = NULL, no_axes = deprecated()) {
     if (inherits(data, "uneval")) {
         cli_abort(c(
             "{.arg data} cannot be {.obj_type_friendly {data}}",
             "i" = "Have you misspelled the {.arg data} argument in {.fn ggalign}"
         ))
     }
-    no_axes <- no_axes %||%
-        getOption(sprintf("%s.align_no_axes", pkg_nm()), default = TRUE)
+    if (lifecycle::is_present(no_axes)) {
+        lifecycle::deprecate_stop(
+            "1.1.0",
+            "ggalign(no_axes = )",
+            details = "Please add `theme()` to the ggplot instead"
+        )
+    }
     assert_active(active)
-    active <- update_active(active, new_active(use = TRUE))
+    active <- active_update(active(use = TRUE), active)
     new_craftbox(
         AlignGg,
         input_data = allow_lambda(data),
@@ -103,7 +106,7 @@ ggalign <- function(data = waiver(), mapping = aes(), ..., size = NULL,
         plot = ggplot(mapping = mapping),
         size = size,
         schemes = default_schemes(data, th = theme_no_strip()),
-        no_axes = no_axes, active = active
+        active = active
     )
 }
 
@@ -131,8 +134,8 @@ AlignGg <- ggproto("AlignGg", Craftsman,
         } else if (is.waive(input_data)) {
             data <- layout_data %|w|% NULL
             # for data inherit from the layout, and the layout data is from
-            # the quad-layout, we'll integrate the `extra_design`
-            self$use_extra_design <- is_stack_layout(layout) &&
+            # the quad-layout, we'll integrate the `extra_domain`
+            self$use_extra_domain <- is_stack_layout(layout) &&
                 isTRUE(layout@heatmap$quad_matrix)
         } else {
             data <- input_data
@@ -141,10 +144,10 @@ AlignGg <- ggproto("AlignGg", Craftsman,
             fortify_data_frame(data, !!!self$data_params, call = self$call)
         )
 
-        # for discrete design, # we need ensure the nobs is the same
-        if (is_discrete_design(design <- layout@design)) {
+        # for discrete domain, # we need ensure the nobs is the same
+        if (is_discrete_domain(domain <- layout@domain)) {
             if (!is.null(data)) {
-                if (is.null(layout_nobs <- design$nobs)) {
+                if (is.na(layout_nobs <- prop(domain, "nobs"))) {
                     layout_nobs <- NROW(data)
                     if (layout_nobs == 0L) {
                         cli_abort("{.arg data} cannot be empty",
@@ -157,7 +160,7 @@ AlignGg <- ggproto("AlignGg", Craftsman,
                         object_name, NROW(data), layout_name, layout_nobs
                     ))
                 }
-                design["nobs"] <- list(layout_nobs)
+                prop(domain, "nobs") <- layout_nobs
 
                 # we always add `.index` to align the observations
                 # For matrix-like object
@@ -167,7 +170,7 @@ AlignGg <- ggproto("AlignGg", Craftsman,
                 } else {
                     plot_data$.index <- seq_len(NROW(data))
                 }
-                layout@design <- design
+                layout@domain <- domain
                 self$labels <- vec_names(data) %||% vec_names(layout_data)
                 # always remove names, we'll add it in `build_plot()`
                 plot_data$.names <- NULL
@@ -179,7 +182,7 @@ AlignGg <- ggproto("AlignGg", Craftsman,
         self$data <- ggalign_data_restore(plot_data, layout_data)
         layout
     },
-    setup_plot = function(self, plot) {
+    init_plot = function(self, plot) {
         direction <- self$direction
         ggadd_default(
             plot,
@@ -202,35 +205,50 @@ AlignGg <- ggproto("AlignGg", Craftsman,
     },
 
     #' @importFrom stats reorder
-    build_plot = function(self, plot, design, extra_design = NULL,
-                          previous_design = NULL) {
+    build_plot = function(self, plot, domain, extra_domain = NULL,
+                          previous_domain = NULL) {
         data <- self$data
 
         # if inherit from the parent layout
-        if (isTRUE(self$use_extra_design) &&
-            is_discrete_design(extra_design) &&
-            !is.null(.subset2(extra_design, "nobs"))) {
+        if (isTRUE(self$use_extra_domain) &&
+            is_discrete_domain(extra_domain) &&
+            !is.na(prop(extra_domain, "nobs"))) {
             # if the data is inherit from the `quad_layout()`
             # the data must be a matrix
             extra_plot_data <- data_frame0(
-                .extra_panel = .subset2(extra_design, "panel"),
-                .extra_index = .subset2(extra_design, "index")
+                .extra_panel = prop(extra_domain, "panel"),
+                .extra_index = prop(extra_domain, "index")
             )
         } else {
             extra_plot_data <- NULL
         }
 
-        if (is_continuous_design(design)) {
-            if (!is.null(data) && !is.null(extra_plot_data)) {
+        if (!is_discrete_domain(domain)) {
+            if (is.data.frame(data) && is.data.frame(extra_plot_data)) {
                 data <- full_join(data, extra_plot_data,
                     by.x = ".column_index", by.y = ".extra_index"
                 )
             }
+            # Treat the first column as the facet column
+            # For continuous domains (used by circle_genomic()), ensure valid
+            # facets
+            if (is_continuous_domain(domain) &&
+                !is.null(prop(domain, "facet_lvls")) &&
+                is.data.frame(data) && ncol(data) > 0L) {
+                missing <- is.na(data[[1L]])
+                if (any(missing)) {
+                    cli_warn("Removing {.val {sum(missing)}} rows with missing {.field facet_lvls}")
+                    data <- vec_slice(data, !missing)
+                }
+                data[[1L]] <- factor(data[[1L]],
+                    levels = prop(domain, "facet_lvls")
+                )
+            }
             return(gguse_data(plot, data))
-        } else if (is.null(.subset2(design, "nobs"))) {
+        } else if (is.na(prop(domain, "nobs"))) {
             cli_abort(c(
                 sprintf(
-                    "you must initialize %s before drawing %s",
+                    "you must initialize {.field nobs} of %s before drawing %s",
                     self$layout_name, object_name(self)
                 ),
                 i = "Or you should use {.fn ggfree}"
@@ -238,8 +256,8 @@ AlignGg <- ggproto("AlignGg", Craftsman,
         }
         direction <- self$direction
         axis <- to_coord_axis(direction)
-        panel <- .subset2(design, "panel")
-        index <- .subset2(design, "index")
+        panel <- prop(domain, "panel")
+        index <- prop(domain, "index")
         coord_name <- paste0(".", axis)
         plot_data <- data_frame0(
             .panel = panel,
@@ -274,11 +292,11 @@ AlignGg <- ggproto("AlignGg", Craftsman,
     finish_plot = function(self, plot, schemes, theme) {
         direction <- self$direction
         # remove axis titles, text, ticks used for alignment
-        if (isTRUE(self$no_axes)) {
-            schemes$scheme_theme <- .subset2(schemes, "scheme_theme") +
-                theme_no_axes(switch_direction(direction, "y", "x"))
-        }
-        plot <- plot_add_schemes(plot, schemes)
+        schemes <- scheme_update(
+            schemes,
+            theme_no_axes(switch_direction(direction, "y", "x"))
+        )
+        plot <- plot_add_scheme(plot, schemes)
         if (is_horizontal(direction)) {
             theme <- theme(
                 panel.spacing.y = calc_element("panel.spacing.y", theme)
