@@ -38,21 +38,27 @@
 #'
 #' @importFrom ggplot2 ggplot aes
 #' @export
-ggcross <- function(mapping = aes(), size = NULL,
-                    no_axes = NULL, active = NULL) {
-    active <- update_active(active, new_active(use = TRUE))
-    no_axes <- no_axes %||%
-        getOption(sprintf("%s.align_no_axes", pkg_nm()), default = TRUE)
+ggcross <- function(mapping = aes(), size = NULL, active = NULL,
+                    no_axes = deprecated()) {
+    assert_active(active)
+    active <- active_update(active(use = TRUE), active)
+    if (lifecycle::is_present(no_axes)) {
+        lifecycle::deprecate_stop(
+            "1.1.0",
+            "ggcross(no_axes = )",
+            details = "Please add `theme()` to the ggplot instead"
+        )
+    }
     cross(
         CrossGg,
         plot = ggplot(mapping = mapping),
         schemes = default_schemes(th = theme_no_strip()),
-        size = size, no_axes = no_axes, active = active
+        size = size, active = active
     )
 }
 
 #' @importFrom ggplot2 ggproto
-CrossGg <- ggproto("CrossGg", 
+CrossGg <- ggproto("CrossGg",
     CraftCross,
     interact_layout = function(self, layout) {
         if (!is_cross_layout(layout)) {
@@ -69,28 +75,28 @@ CrossGg <- ggproto("CrossGg",
         }
 
         # udpate cross_points
-        layout@cross_points <- c(layout@cross_points, length(layout@plot_list))
+        layout@cross_points <- c(layout@cross_points, length(layout@box_list))
 
-        # update old design list
-        layout@odesign <- c(layout@odesign, list(layout@design))
+        # update old domain list
+        layout@odomain <- c(layout@odomain, list(layout@domain))
 
         # we keep the names from the layout data for usage
         self$labels <- vec_names(layout@data)
         layout
     },
-    setup_design = function(self, design) {
-        design["index"] <- list(NULL) # always reset the index
-        design
+    setup_domain = function(self, domain) {
+        prop(domain, "index") <- NULL # always reset the index
+        domain
     },
-    setup_plot = function(self, plot) {
+    init_plot = function(self, plot) {
         ggadd_default(plot, mapping = switch_direction(
             self$direction, aes(y = .data$.y), aes(x = .data$.x)
         ))
     },
     #' @importFrom stats reorder
-    build_plot = function(self, plot, design, extra_design = NULL,
-                          previous_design = NULL) {
-        if (is.null(.subset2(design, "nobs"))) {
+    build_plot = function(self, plot, domain, extra_domain = NULL,
+                          previous_domain = NULL) {
+        if (is.na(prop(domain, "nobs"))) {
             cli_abort(sprintf(
                 "you must initialize %s before drawing %s",
                 self$layout_name, object_name(self)
@@ -98,13 +104,13 @@ CrossGg <- ggproto("CrossGg",
         }
         direction <- self$direction
         index <- vec_c(
-            .subset2(previous_design, "index"),
-            .subset2(design, "index")
+            prop(previous_domain, "index"),
+            prop(domain, "index")
         )
         data <- data_frame0(
             .panel = vec_c(
-                .subset2(previous_design, "panel"),
-                .subset2(design, "panel")
+                prop(previous_domain, "panel"),
+                prop(domain, "panel")
             ),
             .index = index,
             # ggcross() only reset ordering index, labels should be the same
@@ -114,8 +120,8 @@ CrossGg <- ggproto("CrossGg",
                     vec_rep_each(
                         c("left", "right"),
                         c(
-                            .subset2(previous_design, "nobs"),
-                            .subset2(design, "nobs")
+                            prop(previous_domain, "nobs"),
+                            prop(domain, "nobs")
                         )
                     ),
                     c("left", "right")
@@ -125,8 +131,8 @@ CrossGg <- ggproto("CrossGg",
                     vec_rep_each(
                         c("top", "bottom"),
                         c(
-                            .subset2(previous_design, "nobs"),
-                            .subset2(design, "nobs")
+                            prop(previous_domain, "nobs"),
+                            prop(domain, "nobs")
                         )
                     ),
                     c("bottom", "top")
@@ -136,8 +142,8 @@ CrossGg <- ggproto("CrossGg",
         axis <- to_coord_axis(direction)
         coord_name <- paste0(".", axis)
         data[[coord_name]] <- vec_c(
-            seq_len(.subset2(previous_design, "nobs")),
-            seq_len(.subset2(design, "nobs"))
+            seq_len(prop(previous_domain, "nobs")),
+            seq_len(prop(domain, "nobs"))
         )
         if (!is.null(.subset2(data, ".names"))) {
             data[[paste0(".discrete_", axis)]] <- reorder(
@@ -154,24 +160,7 @@ CrossGg <- ggproto("CrossGg",
         )
     },
     finish_plot = function(self, plot, schemes, theme) {
-        direction <- self$direction
-        # remove axis titles, text, ticks used for alignment
-        if (isTRUE(self$no_axes)) {
-            schemes$scheme_theme <- .subset2(schemes, "scheme_theme") +
-                theme_no_axes(switch_direction(direction, "y", "x"))
-        }
-        plot <- plot_add_schemes(plot, schemes)
-        if (is_horizontal(direction)) {
-            theme <- theme(
-                panel.spacing.y = calc_element("panel.spacing.y", theme)
-            )
-        } else {
-            theme <- theme(
-                panel.spacing.x = calc_element("panel.spacing.x", theme)
-            )
-        }
-        plot <- plot + theme
-        ggremove_margin(plot, direction) + theme_recycle()
+        ggproto_parent(AlignGg, self)$finish_plot(plot, schemes, theme)
     },
     summary = function(self, plot) {
         header <- ggproto_parent(Craftsman, self)$summary(plot)
