@@ -13,7 +13,39 @@ default_theme <- function() {
     }
 }
 
+# nocov start
+new_theme_class <- function(new_class) {
+    rlang::new_function(
+        # We utilize editor completion by listing all `theme()` arguments here.
+        # By placing `...` at the beginning, we can check if the first
+        # following argument is a `theme()` object rather than individual theme
+        # elements.
+        c(
+            rlang::exprs(... = ),
+            .subset(
+                rlang::fn_fmls(theme),
+                vec_set_difference(names(rlang::fn_fmls(theme)), "...")
+            )
+        ),
+        quote({
+            elements <- ggfun("find_args")(..., complete = NULL, validate = NULL)
+            ans <- theme(!!!elements)
+            th <- NULL
+            for (i in seq_len(...length())) {
+                if (inherits(t <- ...elt(i), "theme")) {
+                    th <- ggfun("add_theme")(th, t)
+                }
+            }
+            add_class(ggfun("add_theme")(th, ans), new_class)
+        })
+    )
+}
+# nocov end
+
+S3_class_theme <- S7::new_S3_class("theme")
+
 # Check if user has set the theme
+#' @importFrom ggplot2 complete_theme
 is_theme_unset <- function() {
     isTRUE(all.equal(
         complete_theme(ggfun("ggplot_global")$theme_default),
@@ -31,55 +63,46 @@ theme_no_strip <- function() {
     )
 }
 
+#' @importFrom ggplot2 element_rect
 theme_panel_border <- function() theme(panel.border = element_rect(fill = NA))
 
-#' @importFrom utils packageVersion
-#' @importFrom rlang try_fetch
-complete_theme <- function(theme) {
-    if (packageVersion("ggplot2") > "3.5.2") {
-        ggfun("complete_theme")(theme)
-    } else {
-        ggfun("plot_theme")(list(theme = theme))
-    }
-}
-
-#' @importFrom ggplot2 register_theme_elements el_def element_line
+# nocov start
+#' @importFrom ggplot2 register_theme_elements el_def
+#' @importFrom ggplot2 element_line element_polygon element_text
 theme_elements <- function() {
     register_theme_elements(
         ggalign.line = element_line(
             color = "black",
             linewidth = 0.5,
             linetype = 1,
-            lineend = "butt"
+            lineend = "butt",
+            linejoin = "round"
         ),
         ggalign.polygon = element_polygon(
             fill = NA,
-            color = "black",
+            colour = "black",
             linewidth = 0.5,
             linetype = 1,
-            alpha = NA,
-            lineend = "butt",
-            linejoin = "round",
-            linemitre = 10
+            linejoin = "round"
         ),
         element_tree = list(
-            plot.patch_title = el_def("element_text", "text"),
-            plot.patch_title.top = el_def("element_text", "text"),
-            plot.patch_title.left = el_def("element_text", "text"),
-            plot.patch_title.bottom = el_def("element_text", "text"),
-            plot.patch_title.right = el_def("element_text", "text"),
+            plot.patch_title = el_def(element_text, "text"),
+            plot.patch_title.top = el_def(element_text, "text"),
+            plot.patch_title.left = el_def(element_text, "text"),
+            plot.patch_title.bottom = el_def(element_text, "text"),
+            plot.patch_title.right = el_def(element_text, "text"),
             plot.patch_title.position = el_def("character"),
             plot.patch_title.position.top = el_def("character"),
             plot.patch_title.position.left = el_def("character"),
             plot.patch_title.position.bottom = el_def("character"),
             plot.patch_title.position.right = el_def("character"),
             panel.spacing.r = el_def(c("unit", "rel"), "panel.spacing"),
-            ggalign.line = el_def("element_line"),
-            ggalign.curve = el_def("element_curve"),
-            ggalign.polygon = el_def("element_polygon")
+            ggalign.line = el_def(element_line),
+            ggalign.polygon = el_def(element_polygon)
         )
     )
 }
+# nocov end
 
 #' Used to match theme
 #'
@@ -89,8 +112,8 @@ theme_recycle <- function() structure(list(), class = "theme_recycle")
 
 #' @importFrom ggplot2 ggplot_add ggproto ggproto_parent
 #' @export
-ggplot_add.theme_recycle <- function(object, plot, object_name) {
-    ParentFacet <- .subset2(plot, "facet")
+ggplot_add.theme_recycle <- function(object, plot, object_name, ...) {
+    ParentFacet <- plot$facet
     if (!inherits(ParentFacet, c("FacetGrid", "FacetWrap"))) {
         return(plot)
     }
@@ -153,6 +176,7 @@ ggplot_add.theme_recycle <- function(object, plot, object_name) {
 
 #################################################################
 # Apply a function to the vectorized field of the theme object
+#' @importFrom ggplot2 calc_element
 theme_vec <- function(.th, .el, .fn, ...) {
     element <- calc_element(.el, .th)
     if (inherits(element, "element")) {
