@@ -50,14 +50,14 @@ layer_order.ggalign_layer_order <- function(layer, order = 0) {
 
 #' @importFrom ggplot2 ggplot_add
 #' @export
-ggplot_add.ggalign_layer_order <- function(object, plot, object_name) {
+ggplot_add.ggalign_layer_order <- function(object, plot, object_name, ...) {
     # ggplot2 will do something special for the layer
     # add layer_name, we re-call the method for the layer
     ans <- ggplot_add(
         .subset2(object, "object"),
         plot, .subset2(object, "object_name")
     )
-    if ((cur <- length(layers <- .subset2(ans, "layers"))) == 1L) {
+    if ((cur <- length(layers <- ans$layers)) == 1L) {
         return(ans)
     }
     order <- .subset2(object, "order")
