@@ -109,11 +109,11 @@ circle_discrete.default <- function(data = NULL, ..., radial = NULL,
         # if we have provided data, we initialize the `nobs`
         nobs <- vec_size(data)
     } else {
-        nobs <- NULL
+        nobs <- NA_integer_
     }
     new_circle_layout(
         data = data,
-        design = discrete_design(nobs = nobs),
+        domain = DiscreteDomain(nobs = nobs),
         radial = radial, direction = direction, sector_spacing = sector_spacing,
         schemes = schemes, theme = theme, spacing_theta = spacing_theta
     )
@@ -161,7 +161,7 @@ circle_continuous.default <- function(data = NULL, ..., radial = NULL,
     data <- fortify_data_frame(data = data, ...)
     schemes <- default_schemes()
     new_circle_layout(
-        data = data, design = limits,
+        data = data, domain = limits,
         radial = radial, direction = direction, sector_spacing = sector_spacing,
         schemes = schemes, theme = theme, spacing_theta = spacing_theta
     )
@@ -179,8 +179,7 @@ circle_continuous.function <- function(data = NULL, ...) {
 #' @export
 circle_continuous.formula <- circle_continuous.function
 
-#' @importFrom methods new
-new_circle_layout <- function(data, design, radial, direction,
+new_circle_layout <- function(data, domain, radial, direction,
                               sector_spacing = NULL, schemes = NULL,
                               theme = NULL, name = NULL,
                               spacing_theta = deprecated(),
@@ -193,16 +192,19 @@ new_circle_layout <- function(data, design, radial, direction,
     }
     if (!is.null(radial) && abs(diff(radial$arc)) < pi / 2L) {
         cli_abort(
-            "Cannot use circle of acute angle < 90 in {.arg radial}",
+            "Cannot create circle of acute angle < 90 in {.arg radial}",
             call = call
         )
     }
-    direction <- arg_match0(direction, c("inward", "outward"))
+    direction <- arg_match0(direction,
+        c("inward", "outward"),
+        error_call = call
+    )
     if (is.null(name)) {
-        if (is_continuous_design(design)) {
-            name <- "circle_continuous"
-        } else {
+        if (is_discrete_domain(domain)) {
             name <- "circle_discrete"
+        } else {
+            name <- "circle_continuous"
         }
     }
     if (lifecycle::is_present(spacing_theta)) {
@@ -211,26 +213,18 @@ new_circle_layout <- function(data, design, radial, direction,
             "facet_sector(spacing_theta = )",
             "facet_sector(sector_spacing = )"
         )
-        if (is.null(sector_spacing)) sector_spacing <- spacing_theta
+        sector_spacing <- sector_spacing %||% spacing_theta
     }
-    new(
-        "CircleLayout",
+    if (!is.null(sector_spacing) && !is.numeric(sector_spacing)) {
+        cli_abort("{.arg sector_spacing} must be a {.cls numeric}", call = call)
+    }
+    CircleLayout(
         name = name, data = data,
         schemes = schemes, # used by the layout
-        design = design,
+        domain = domain,
         sector_spacing = sector_spacing,
         theme = theme,
-        radial = radial, direction = direction
+        radial = radial,
+        direction = direction
     )
 }
-
-############################################################
-# Used to place multiple objects in one axis
-#' @importFrom grid unit
-#' @importFrom ggplot2 waiver
-#' @keywords internal
-#' @include layout-chain-.R
-methods::setClass("CircleLayout",
-    contains = "ChainLayout",
-    list(radial = "ANY", sector_spacing = "ANY", direction = "character")
-)
