@@ -1,6 +1,6 @@
 #' @export
-ggalign_build.StackLayout <- function(x) {
-    x <- default_layout(x)
+`ggalign_build.ggalign::StackLayout` <- function(x) {
+    x <- layout_init(x)
     (stack_build(x) %||% align_plots(theme = x@theme)) +
         layout_title(
             title = .subset2(x@titles, "title"),
@@ -10,11 +10,11 @@ ggalign_build.StackLayout <- function(x) {
 }
 
 #' @param schemes,theme Parameters from parent layout
-#' @param extra_design layout parameters of the axis vertically with the stack.
+#' @param extra_domain layout parameters of the axis vertically with the stack.
 #' @noRd
 stack_build <- function(stack, schemes = NULL, theme = NULL,
-                        extra_design = NULL) {
-    if (is_empty(stack@plot_list)) {
+                        extra_domain = NULL) {
+    if (is_empty(stack@box_list)) {
         return(NULL)
     }
     direction <- stack@direction
@@ -23,23 +23,11 @@ stack_build <- function(stack, schemes = NULL, theme = NULL,
 
     if (is_horizontal(direction)) {
         spacing <- "y"
-        # for horizontal stack, we by default remove top and bottom spaces
-        # if (!is.null(position)) {
-        #     schemes$scheme_align["free_spaces"] <- list(
-        #         .subset2(schemes$scheme_align, "free_spaces") %|w|% "tb"
-        #     )
-        # }
     } else {
         spacing <- "x"
-        # for vertical stack, we by default remove left and right spaces
-        # if (!is.null(position)) {
-        #     schemes$scheme_align["free_spaces"] <- list(
-        #         .subset2(schemes$scheme_align, "free_spaces") %|w|% "lr"
-        #     )
-        # }
     }
     theme <- inherit_parent_layout_theme(stack, theme, spacing = spacing)
-    composer <- stack_build_composer(stack, schemes, theme, extra_design)
+    composer <- resolve_stack_layout(stack, schemes, theme, extra_domain)
     if (is_empty(plots <- .subset2(composer, "plots"))) {
         return(NULL)
     }
@@ -47,7 +35,7 @@ stack_build <- function(stack, schemes = NULL, theme = NULL,
     # arrange plots
     if (is.null(position)) { # for stack layout
         # sizes should be of length 3
-        sizes <- stack@sizes
+        sizes <- convert(stack@sizes, S3_unit)
         # recycle the sizes when necessary
         if (length(sizes) == 1L) sizes <- rep(sizes, length.out = 3L)
         sizes <- sizes[
@@ -78,9 +66,9 @@ stack_build <- function(stack, schemes = NULL, theme = NULL,
             sizes,
             do.call(unit.c, .subset2(composer, "sizes"))
         ),
-        guides = .subset2(.subset2(schemes, "scheme_align"), "guides"),
+        guides = prop(schemes_get(schemes, "scheme_align"), "guides"),
         theme = stack@theme
-    )
+    ) + layout_tags(NULL)
 
     # for annotation, we should always make it next to the main body
     if (is.null(position)) {
@@ -111,8 +99,8 @@ stack_build <- function(stack, schemes = NULL, theme = NULL,
     free_guides <- .subset2(stack@heatmap, "free_guides")
     if (!is.waive(free_guides)) plot <- free_guide(plot, free_guides)
     # we also apply the `free_spaces` for the whole annotation stack
-    free_spaces <- .subset2(
-        .subset2(schemes, "scheme_align"), "free_spaces"
+    free_spaces <- prop(
+        schemes_get(schemes, "scheme_align"), "free_spaces"
     ) %|w|% NULL
     if (!is.null(free_spaces)) {
         plot <- free_space(free_border(plot, free_spaces), free_spaces)
@@ -123,35 +111,35 @@ stack_build <- function(stack, schemes = NULL, theme = NULL,
 #' @param schemes,theme Parameters for current stack, which have inherited
 #' parameters from the parent.
 #' @noRd
-stack_build_composer <- function(stack, schemes, theme, extra_design) {
-    UseMethod("stack_build_composer")
+resolve_stack_layout <- function(stack, schemes, theme, extra_domain) {
+    UseMethod("resolve_stack_layout")
 }
 
 #' @export
-stack_build_composer.StackLayout <- function(stack, schemes, theme,
-                                             extra_design) {
-    plot_list <- stack@plot_list
+`resolve_stack_layout.ggalign::StackLayout` <- function(stack, schemes, theme,
+                                                        extra_domain) {
+    box_list <- stack@box_list
     direction <- stack@direction
     position <- .subset2(stack@heatmap, "position")
 
     # we remove the plot without actual plot area
-    keep <- vapply(plot_list, function(plot) {
+    keep <- vapply(box_list, function(box) {
         # we remove objects without plot area
         # Now, only `CraftBox` will contain `NULL`
-        !is_craftbox(plot) || !is.null(plot@plot)
+        !is_craftbox(box) || !is.null(box@plot)
     }, logical(1L), USE.NAMES = FALSE)
-    plot_list <- .subset(plot_list, keep)
-    if (is_empty(plot_list)) return(NULL) # styler: off
+    box_list <- .subset(box_list, keep)
+    if (is_empty(box_list)) return(NULL) # styler: off
 
     # we reorder the plots based on the `order` slot
-    plot_order <- vapply(plot_list, function(plot) {
-        if (is_layout(plot)) {
-            .subset2(plot@plot_active, "order")
+    plot_order <- vapply(box_list, function(box) {
+        if (is_craftbox(box)) {
+            prop(box@active, "order")
         } else {
-            .subset2(plot@active, "order")
+            prop(box@plot_active, "order")
         }
     }, integer(1L), USE.NAMES = FALSE)
-    plot_list <- .subset(plot_list, make_order(plot_order))
+    box_list <- .subset(box_list, make_order(plot_order))
 
     # build the stack
     composer <- stack_composer(direction)
@@ -193,25 +181,26 @@ stack_build_composer.StackLayout <- function(stack, schemes, theme,
     #     p3 + theme(plot.margin = margin(l = 5, unit = "cm")),
     #     ncol = 1
     # )
-    stack_spaces <- .subset2(.subset2(schemes, "scheme_align"), "free_spaces")
+    stack_spaces <- prop(schemes_get(schemes, "scheme_align"), "free_spaces")
     if (is_string(stack_spaces) && !is.null(position)) {
         released_spaces <- stack_spaces
     } else {
         released_spaces <- NULL
     }
 
-    design <- setup_design(stack@design)
+    domain <- domain_init(stack@domain)
     stack_composer_add(
-        plot_list,
+        box_list,
+        stack = stack,
         composer,
         schemes = schemes,
         theme = theme,
-        design = design,
-        extra_design = extra_design,
+        domain = domain,
+        extra_domain = extra_domain,
         direction = direction,
         position = position,
         released_spaces = released_spaces,
-        previous_design = NULL
+        previous_domain = NULL
     )
 }
 
