@@ -35,42 +35,33 @@ stack_crossh <- function(data = NULL, ...) {
     stack_cross(data = data, direction = "h", ...)
 }
 
-#' @include layout-chain-stack-.R
-methods::setClass(
-    "StackCross",
-    contains = "StackLayout",
-    # A list of old design
-    list(odesign = "list", cross_points = "integer", break_points = "integer"),
-    prototype = list(
-        odesign = list(),
-        cross_points = integer(),
-        break_points = integer()
-    )
-)
-
+#' @importFrom S7 convert
 #' @export
 stack_cross.default <- function(direction, data = NULL, ...) {
     ans <- stack_discrete(data = data, direction = direction, ...)
-    ans <- methods::as(ans, "StackCross")
-    ans@name <- "stack_cross"
+    ans <- convert(ans, StackCross)
+    attr(ans, "name") <- "stack_cross"
     ans
 }
 
 #' @importFrom grid unit.c
 #' @importFrom rlang is_empty is_string
-stack_build_composer.StackCross <- function(stack, schemes, theme,
-                                            extra_design) {
+`resolve_stack_layout.ggalign::StackCross` <- function(stack, schemes, theme,
+                                            extra_domain) {
     # check if we should initialize the layout observations
-    layout_design <- stack@design
-    if (is_discrete_design(layout_design) &&
-        is.null(.subset2(layout_design, "nobs")) &&
-        any(vapply(plot_list, is_cross_plot, logical(1L), USE.NAMES = FALSE))) {
+    layout_domain <- stack@domain
+    # styler: off
+    if (is_discrete_domain(layout_domain) &&
+        is.na(prop(layout_domain, "nobs")) &&
+        any(vapply(plot_list, is_cross_craftbox, logical(1L),
+                   USE.NAMES = FALSE))) {
         cli_abort(sprintf(
             "You must initialize the layout observations to plot the %s",
             object_name(stack)
         ))
     }
-    plot_list <- stack@plot_list
+    # styler: on
+    plot_list <- stack@box_list
 
     direction <- stack@direction
     position <- .subset2(stack@heatmap, "position")
@@ -78,7 +69,7 @@ stack_build_composer.StackCross <- function(stack, schemes, theme,
         plot_list,
         sizes = diff(c(0L, stack@cross_points, length(plot_list)))
     )
-    design_list <- c(stack@odesign, list(layout_design))
+    domain_list <- c(stack@odomain, list(layout_domain))
 
     # build the stack
     composer <- stack_composer(direction)
@@ -88,22 +79,21 @@ stack_build_composer.StackCross <- function(stack, schemes, theme,
     # by the layout will overlap with the axis of the plot in the layout.
     #
     # this occurs in the annotation stack (`position` is not `NULL`).
-    stack_spaces <- .subset2(.subset2(schemes, "scheme_align"), "free_spaces")
+    stack_spaces <- prop(schemes_get(schemes, "scheme_align"), "free_spaces")
     if (is_string(stack_spaces) && !is.null(position)) {
         released_spaces <- stack_spaces
     } else {
         released_spaces <- NULL
     }
-    previous_design <- NULL
+    previous_domain <- NULL
     for (i in seq_along(plot_list)) {
         plots <- .subset2(plot_list, i)
 
-        # prepare design for current group
-        design <- .subset2(design_list, i)
-        design <- setup_design(design)
+        # prepare domain for current group
+        domain <- domain_init(.subset2(domain_list, i))
 
         if (is_empty(plots)) {
-            previous_design <- design
+            previous_domain <- domain
             next
         }
 
@@ -116,35 +106,36 @@ stack_build_composer.StackCross <- function(stack, schemes, theme,
         plots <- .subset(plots, keep)
 
         if (is_empty(plots)) {
-            previous_design <- design
+            previous_domain <- domain
             next
         }
 
         # we reorder the plots based on the `order` slot
         plot_order <- vapply(plots, function(plot) {
             # always keep cross() in the start
-            if (is_cross_plot(plot)) {
+            if (is_cross_craftbox(plot)) {
                 1L
             } else if (is_craftbox(plot)) {
-                .subset2(plot@active, "order")
+                prop(plot@active, "order")
             } else {
-                .subset2(plot@plot_active, "order")
+                prop(plot@plot_active, "order")
             }
         }, integer(1L), USE.NAMES = FALSE)
         plots <- .subset(plots, make_order(plot_order))
         composer <- stack_composer_add(
             plots,
+            stack = stack,
             composer,
             schemes = schemes,
             theme = theme,
-            design = design,
-            extra_design = extra_design,
+            domain = domain,
+            extra_domain = extra_domain,
             direction = direction,
             position = position,
             released_spaces = released_spaces,
-            previous_design = previous_design
+            previous_domain = previous_domain
         )
-        previous_design <- design
+        previous_domain <- domain
     }
     composer
 }
