@@ -196,11 +196,9 @@ quad_continuous.uneval <- function(data, ...) {
 
 #####################################################
 #' @importFrom ggplot2 ggplot
-#' @importFrom methods new
 new_quad_layout <- function(name, data, xlim = waiver(), ylim = waiver(),
                             mapping = aes(), theme = NULL, active = NULL,
                             width = NA, height = NA,
-                            class = "QuadLayout",
                             call = caller_call()) {
     if (!is.waive(xlim)) assert_limits(xlim, call = call)
     if (!is.waive(ylim)) assert_limits(ylim, call = call)
@@ -219,12 +217,12 @@ new_quad_layout <- function(name, data, xlim = waiver(), ylim = waiver(),
                 cli_abort("empty data is no allowed")
             }
         } else {
-            nrows <- NULL
-            ncols <- NULL
+            nrows <- NA_integer_
+            ncols <- NA_integer_
         }
     }
-    horizontal <- ylim %|w|% discrete_design(nobs = nrows)
-    vertical <- xlim %|w|% discrete_design(nobs = ncols)
+    horizontal <- ylim %|w|% DiscreteDomain(nobs = nrows)
+    vertical <- xlim %|w|% DiscreteDomain(nobs = ncols)
 
     # always remove default axis titles
     # https://stackoverflow.com/questions/72402570/why-doesnt-gplot2labs-overwrite-update-the-name-argument-of-scales-function
@@ -253,12 +251,11 @@ new_quad_layout <- function(name, data, xlim = waiver(), ylim = waiver(),
     assert_active(active, call = call)
 
     # Here we use S4 object to override the double dispatch of `+.gg` method
-    new(
-        class,
+    QuadLayout(
         # used by the layout
         data = data, theme = theme,
         schemes = schemes,
-        plot_active = update_active(active, new_active(use = TRUE)),
+        plot_active = active_update(active(use = TRUE), active),
         name = name,
         # used by the main body
         body_schemes = default_schemes(waiver()),
@@ -268,36 +265,3 @@ new_quad_layout <- function(name, data, xlim = waiver(), ylim = waiver(),
         plot = plot, horizontal = horizontal, vertical = vertical
     )
 }
-
-# Used to create the QuadLayout
-#' @include layout-.R
-methods::setClass(
-    "QuadLayout",
-    contains = "LayoutProto",
-    list(
-        data = "ANY", plot = "ANY", body_schemes = "list", name = "character",
-        # parameters for main body
-        width = "ANY", height = "ANY",
-        # Used to align axis
-        horizontal = "ANY", vertical = "ANY",
-        # top, left, bottom, right must be a StackLayout object.
-        top = "ANY", left = "ANY", bottom = "ANY", right = "ANY",
-        # If we regard `QuadLayout` as a plot, and put it into the stack
-        # layout, we need following arguments to control it's behavour
-        plot_active = "ANY"
-    ),
-    prototype = list(
-        # used by QuadLayout
-        top = NULL, left = NULL, bottom = NULL, right = NULL
-    )
-)
-
-#' @export
-is_layout_discrete.QuadLayout <- function(x, direction, ...) {
-    is_discrete_design(slot(x, direction))
-}
-
-#' @export
-is_layout_continuous.QuadLayout <- function(x, direction, ...) {
-    is_continuous_design(slot(x, direction))
-}
