@@ -1,7 +1,7 @@
 #' @importFrom grid unit.c
 #' @export
-ggalign_build.QuadLayout <- function(x) {
-    x <- default_layout(x)
+`ggalign_build.ggalign::QuadLayout` <- function(x) {
+    x <- layout_init(x)
     patches <- quad_build(x)
     plots <- .subset2(patches, "plots")
     sizes <- .subset2(patches, "sizes")
@@ -32,13 +32,13 @@ ggalign_build.QuadLayout <- function(x) {
         design = design,
         heights = .subset2(sizes, "height"),
         widths = .subset2(sizes, "width"),
-        guides = .subset2(.subset2(x@schemes, "scheme_align"), "guides"),
+        guides = prop(schemes_get(x@schemes, "scheme_align"), "guides"),
         theme = x@theme
     ) + layout_title(
         title = .subset2(titles, "title"),
         subtitle = .subset2(titles, "subtitle"),
         caption = .subset2(titles, "caption")
-    )
+    ) + layout_tags(NULL)
 }
 
 quad_build <- function(quad, schemes = NULL, theme = NULL,
@@ -51,13 +51,14 @@ quad_build <- function(quad, schemes = NULL, theme = NULL,
 #' @importFrom ggplot2 aes
 #' @importFrom rlang is_empty
 #' @importFrom grid unit is.unit unit.c
+#' @importFrom S7 convert
 #' @export
 #' @noRd
-quad_build.QuadLayout <- function(quad, schemes = NULL, theme = NULL,
-                                  direction = NULL) {
+`quad_build.ggalign::QuadLayout` <- function(quad, schemes = NULL, theme = NULL,
+                                             direction = NULL) {
     data <- quad@data
-    row_design <- setup_design(quad@horizontal)
-    column_design <- setup_design(quad@vertical)
+    row_domain <- domain_init(quad@horizontal)
+    column_domain <- domain_init(quad@vertical)
     if (is.function(data)) {
         cli_abort(c(
             "{.arg data} cannot be a {.cls function}",
@@ -67,15 +68,15 @@ quad_build.QuadLayout <- function(quad, schemes = NULL, theme = NULL,
             )
         ))
     }
-    if (is_discrete_design(row_design) &&
-        is.null(.subset2(row_design, "nobs"))) {
+    if (is_discrete_domain(row_domain) &&
+        is.na(prop(row_domain, "nobs"))) {
         cli_abort(sprintf(
             "you must initialize %s before drawing the main plot",
             object_name(quad),
         ))
     }
-    if (is_discrete_design(column_design) &&
-        is.null(.subset2(column_design, "nobs"))) {
+    if (is_discrete_domain(column_domain) &&
+        is.na(prop(column_domain, "nobs"))) {
         cli_abort(sprintf(
             "you must initialize %s before drawing the main plot",
             object_name(quad),
@@ -93,57 +94,61 @@ quad_build.QuadLayout <- function(quad, schemes = NULL, theme = NULL,
 
     # prepare action for vertical and horizontal stack layout
     vertical_align <- horizontal_align <- the_align <-
-        .subset2(schemes, "scheme_align")
-    if (!is.null(layout_labs <- .subset2(the_align, "free_labs")) &&
+        schemes_get(schemes, "scheme_align")
+    if (!is.null(layout_labs <- prop(the_align, "free_labs")) &&
         !is.waive(layout_labs)) {
         # prepare labs for child stack layout
-        horizontal_align$free_labs <- gsub("[lr]", "", layout_labs)
-        vertical_align$free_labs <- gsub("[tb]", "", layout_labs)
-        if (!nzchar(horizontal_align$free_labs)) {
-            horizontal_align["free_labs"] <- list(NULL)
+        prop(horizontal_align, "free_labs", check = FALSE) <-
+            gsub("[lr]", "", layout_labs)
+        prop(vertical_align, "free_labs", check = FALSE) <-
+            gsub("[tb]", "", layout_labs)
+        if (!nzchar(prop(horizontal_align, "free_labs"))) {
+            prop(horizontal_align, "free_labs", check = FALSE) <- NULL
         }
-        if (!nzchar(vertical_align$free_labs)) {
-            vertical_align["free_labs"] <- list(NULL)
+        if (!nzchar(prop(vertical_align, "free_labs"))) {
+            prop(vertical_align, "free_labs", check = FALSE) <- NULL
         }
     }
 
     # inherit from the parent stack layout
-    if (!is.null(layout_spaces <- .subset2(the_align, "free_spaces")) &&
+    if (!is.null(layout_spaces <- prop(the_align, "free_spaces")) &&
         !is.waive(layout_spaces)) {
-        horizontal_align$free_spaces <- gsub("[lr]", "", layout_spaces)
-        vertical_align$free_spaces <- gsub("[tb]", "", layout_spaces)
-        if (!nzchar(horizontal_align$free_spaces)) {
-            horizontal_align["free_spaces"] <- list(NULL)
+        prop(horizontal_align, "free_spaces", check = FALSE) <-
+            gsub("[lr]", "", layout_spaces)
+        prop(vertical_align, "free_spaces", check = FALSE) <-
+            gsub("[tb]", "", layout_spaces)
+        if (!nzchar(prop(horizontal_align, "free_spaces"))) {
+            prop(horizontal_align, "free_spaces", check = FALSE) <- NULL
         }
-        if (!nzchar(vertical_align$free_spaces)) {
-            vertical_align["free_spaces"] <- list(NULL)
+        if (!nzchar(prop(vertical_align, "free_spaces"))) {
+            prop(vertical_align, "free_spaces", check = FALSE) <- NULL
         }
     }
 
     # plot annotations ----------------------------
     stack_list <- lapply(.TLBR, function(position) {
-        if (is_empty(stack <- slot(quad, position))) {
+        if (is_empty(stack <- prop(quad, position))) {
             return(list(plot = NULL, size = NULL))
         }
         pschemes <- schemes
         # inherit from horizontal align or vertical align
         if (is_horizontal(to_direction(position))) {
-            extra_design <- column_design
-            pschemes$scheme_align <- horizontal_align
+            extra_domain <- column_domain
+            pschemes <- schemes_set(pschemes, horizontal_align, check = FALSE)
         } else {
-            extra_design <- row_design
-            pschemes$scheme_align <- vertical_align
+            extra_domain <- row_domain
+            pschemes <- schemes_set(pschemes, vertical_align, check = FALSE)
         }
         plot <- stack_build(
             stack,
             schemes = pschemes,
             theme = theme,
-            extra_design = extra_design
+            extra_domain = extra_domain
         )
         if (is.null(plot)) {
             size <- NULL
         } else {
-            size <- stack@sizes
+            size <- convert(stack@sizes, S3_unit)
         }
         list(plot = plot, size = size)
     })
@@ -155,114 +160,70 @@ quad_build.QuadLayout <- function(quad, schemes = NULL, theme = NULL,
     # read the plot ---------------------------------------
     p <- quad@plot
 
-    # setup the facet -----------------------------------
-    do_row_facet <- is_discrete_design(row_design) &&
-        nlevels(.subset2(row_design, "panel")) > 1L
-    do_column_facet <- is_discrete_design(column_design) &&
-        nlevels(.subset2(column_design, "panel")) > 1L
-
-    if (do_row_facet && do_column_facet) {
-        default_facet <- ggplot2::facet_grid(
-            rows = ggplot2::vars(.data$.panel_y),
-            cols = ggplot2::vars(.data$.panel_x),
-            scales = "free", space = "free",
-            drop = FALSE, as.table = FALSE
-        )
-        free_row <- FALSE
-        free_column <- FALSE
-    } else if (do_row_facet) {
-        default_facet <- ggplot2::facet_grid(
-            rows = ggplot2::vars(.data$.panel_y),
-            scales = "free_y", space = "free",
-            drop = FALSE, as.table = FALSE
-        )
-        free_row <- FALSE
-        free_column <- is_continuous_design(column_design)
-    } else if (do_column_facet) {
-        default_facet <- ggplot2::facet_grid(
-            cols = ggplot2::vars(.data$.panel_x),
-            scales = "free_x", space = "free",
-            drop = FALSE, as.table = FALSE
-        )
-        free_row <- is_continuous_design(row_design)
-        free_column <- FALSE
-    } else {
-        default_facet <- facet_quad(object_name(quad))
-        free_row <- is_continuous_design(row_design)
-        free_column <- is_continuous_design(column_design)
-    }
-
     # set the facets and coord ---------------------------
-    # we don't align observations for `quad_free()`
-    # add default data ----------------------------------
-    p <- gguse_data(p, quad_build_data(data, row_design, column_design))
-    p <- gguse_linear_coord(p, object_name(quad))
-    p <- gguse_facet(p, default_facet,
-        free_row = free_row, free_column = free_column
-    )
+    p <- align_quad_facet(p, row_domain, column_domain, object_name(quad))
+    p <- gguse_linear_coord(p, ggplot2::coord_cartesian(), object_name(quad))
+
     p <- p +
-        ggalign_design(
-            x = column_design, y = row_design,
-            xlabels = .subset(
-                colnames(data),
-                .subset2(column_design, "index")
-            ),
-            ylabels = .subset(
-                vec_names(data),
-                .subset2(row_design, "index")
-            )
+        layout_align(
+            x = column_domain, y = row_domain,
+            xlabels = colnames(data), ylabels = vec_names(data)
         )
 
+    # add default data ----------------------------------
+    p <- gguse_data(p, quad_build_data(data, row_domain, column_domain))
+
     # add action ----------------------------------------
-    p <- plot_add_schemes(p, inherit_schemes(quad@body_schemes, schemes))
-    if (do_row_facet) {
-        p <- p + theme(panel.spacing.y = calc_element("panel.spacing.y", theme))
-    }
-    if (do_column_facet) {
-        p <- p + theme(panel.spacing.x = calc_element("panel.spacing.x", theme))
-    }
+    p <- plot_add_scheme(p, scheme_inherit(schemes, quad@body_schemes))
+    p <- p + theme(
+        panel.spacing.x = calc_element("panel.spacing.x", theme),
+        panel.spacing.y = calc_element("panel.spacing.y", theme)
+    )
     p <- p + theme_recycle()
 
     # collect all plots and sizes ----------------------
     plots <- append(plots, list(main = p), 2L)
     sizes <- append(
         sizes,
-        list(main = list(width = quad@width, height = quad@height)),
+        list(main = list(
+            width = convert(quad@width, S3_unit),
+            height = convert(quad@height, S3_unit)
+        )),
         3L
     )
     list(plots = plots, sizes = sizes)
 }
 
 #' @importFrom stats reorder
-quad_build_data <- function(data, row_design, column_design) {
+quad_build_data <- function(data, row_domain, column_domain) {
     if (is.null(data) ||
-        (is_continuous_design(row_design) &&
-            is_continuous_design(column_design))) {
+        (!is_discrete_domain(row_domain) &&
+            !is_discrete_domain(column_domain))) {
         return(data)
     }
-    if (is_discrete_design(row_design)) {
-        row_panel <- .subset2(row_design, "panel")
-        row_index <- .subset2(row_design, "index")
+    if (is_discrete_domain(row_domain)) {
+        row_panel <- prop(row_domain, "panel")
+        row_index <- prop(row_domain, "index")
         row_data <- data_frame0(
             .panel_y = row_panel,
             .index_y = row_index,
             .y = seq_along(row_index)
         )
     }
-    if (is_discrete_design(column_design)) {
-        column_panel <- .subset2(column_design, "panel")
-        column_index <- .subset2(column_design, "index")
+    if (is_discrete_domain(column_domain)) {
+        column_panel <- prop(column_domain, "panel")
+        column_index <- prop(column_domain, "index")
         column_data <- data_frame0(
             .panel_x = column_panel,
             .index_x = column_index,
             .x = seq_along(column_index)
         )
     }
-    if (is_discrete_design(row_design) && is_discrete_design(column_design)) {
+    if (is_discrete_domain(row_domain) && is_discrete_domain(column_domain)) {
         panel_data <- cross_join(row_data, column_data)
         by.x <- c(".column_index", ".row_index")
         by.y <- c(".index_x", ".index_y")
-    } else if (is_discrete_design(column_design)) {
+    } else if (is_discrete_domain(column_domain)) {
         panel_data <- column_data
         by.x <- ".column_index"
         by.y <- ".index_x"
@@ -274,7 +235,7 @@ quad_build_data <- function(data, row_design, column_design) {
     ans <- fortify_data_frame.matrix(data)
     ans <- full_join(ans, panel_data, by.x = by.x, by.y = by.y)
     if (!is.null(.subset2(ans, ".row_names")) &&
-        is_discrete_design(row_design)) {
+        is_discrete_domain(row_domain)) {
         ans$.discrete_y <- reorder(
             .subset2(ans, ".row_names"),
             .subset2(ans, ".y"),
@@ -282,7 +243,7 @@ quad_build_data <- function(data, row_design, column_design) {
         )
     }
     if (!is.null(.subset2(ans, ".column_names")) &&
-        is_discrete_design(column_design)) {
+        is_discrete_domain(column_domain)) {
         ans$.discrete_x <- reorder(
             .subset2(ans, ".column_names"),
             .subset2(ans, ".x"),
