@@ -23,6 +23,12 @@ mark_draw <- function(.draw, ...) {
     if (!is.function(draw <- allow_lambda(.draw))) {
         cli_abort("{.arg .draw} must be a function")
     }
+    args <- names(formals(draw))
+    if (length(args) < 2L && args != "...") {
+        cli_abort(
+            "{.arg .draw} must be a function that takes at least two arguments"
+        )
+    }
     new_draw <- function(data) {
         ans <- lapply(data, function(dd) {
             draw(.subset2(dd, "panel"), .subset2(dd, "link"))
@@ -59,6 +65,12 @@ mark_draw <- function(.draw, ...) {
     if (!is.function(draw <- allow_lambda(.draw))) {
         cli_abort("{.arg .draw} must be a function", call = call)
     }
+    args <- names(formals(draw))
+    if (length(args) < 1L && args != "...") {
+        cli_abort(
+            "{.arg .draw} must be a function that takes at least one argument"
+        )
+    }
     links <- pair_links(...)
     structure(list(draw = draw, links = links), class = "ggalign_mark_draw")
 }
@@ -79,10 +91,15 @@ print.ggalign_mark_draw <- function(x, ...) {
 #'   you can wrap the element with [`I()`] to recycle to match the drawing
 #'   groups. The drawing groups typically correspond to the number of
 #'   observations, as each observation will be linked with the plot panel.
-#' @importFrom ggplot2 element_line
+#' @importFrom ggplot2 element_line complete_theme is_theme_element
 #' @export
 mark_line <- function(..., .element = NULL) {
-    assert_s3_class(.element, "element_line", allow_null = TRUE)
+    assert_s3_class(.element,
+        is_theme_element,
+        "element_line",
+        type = "line",
+        allow_null = TRUE
+    )
     default <- calc_element("ggalign.line", complete_theme(theme_get()))
     if (is.null(.element)) {
         .element <- default
@@ -129,16 +146,22 @@ mark_line <- function(..., .element = NULL) {
 #' Link the observations and the panel with a quadrilateral
 #'
 #' @inheritParams .mark_draw
-#' @param .element A [`element_polygon()`] object. Vectorized fields will be
-#'   recycled to match the total number of groups, or you can wrap the element
-#'   with [`I()`] to recycle to match the drawing groups. The drawing groups
-#'   are usually the same as the defined groups, but they will differ when the
-#'   defined group of observations is separated and cannot be linked with a
-#'   single quadrilateral. In such cases, the number of drawing groups will be
-#'   larger than the number of defined groups.
+#' @param .element A [`element_polygon()`][ggplot2::element_polygon] object.
+#'   Vectorized fields will be recycled to match the total number of groups, or
+#'   you can wrap the element with [`I()`] to recycle to match the drawing
+#'   groups. The drawing groups are usually the same as the defined groups, but
+#'   they will differ when the defined group of observations is separated and
+#'   cannot be linked with a single quadrilateral. In such cases, the number of
+#'   drawing groups will be larger than the number of defined groups.
+#' @importFrom ggplot2 is_theme_element
 #' @export
 mark_tetragon <- function(..., .element = NULL) {
-    assert_s3_class(.element, "element_polygon", allow_null = TRUE)
+    assert_s3_class(.element,
+        is_theme_element,
+        "element_polygon",
+        type = "polygon",
+        allow_null = TRUE
+    )
     default <- calc_element("ggalign.polygon", complete_theme(theme_get()))
     if (is.null(.element)) {
         .element <- default
@@ -196,9 +219,10 @@ mark_tetragon <- function(..., .element = NULL) {
 #' @inheritParams .mark_draw
 #' @param orientation A single string, either `"plot"` or `"observation"`,
 #'   indicating the base of the triangle.
-#' @param .element An [`element_polygon()`] object. Vectorized fields will be
-#'   recycled to match the total number of groups, or you can wrap the element
-#'   with [`I()`] to recycle to match the drawing groups.
+#' @param .element An [`element_polygon()`][ggplot2::element_polygon] object.
+#'   Vectorized fields will be recycled to match the total number of groups, or
+#'   you can wrap the element with [`I()`] to recycle to match the drawing
+#'   groups.
 #'   - When `orientation` is `"plot"`, the drawing groups typically correspond
 #'     to the number of observations.
 #'   - When `orientation` is `"observation"`, the drawing groups usually match
@@ -209,7 +233,12 @@ mark_tetragon <- function(..., .element = NULL) {
 #' @importFrom rlang arg_match0
 #' @export
 mark_triangle <- function(..., orientation = "plot", .element = NULL) {
-    assert_s3_class(.element, "element_polygon", allow_null = TRUE)
+    assert_s3_class(.element,
+        is_theme_element,
+        "element_polygon",
+        type = "polygon",
+        allow_null = TRUE
+    )
     default <- calc_element("ggalign.polygon", complete_theme(theme_get()))
     if (is.null(.element)) {
         .element <- default
@@ -300,11 +329,14 @@ alignpatch.ggalign_mark_plot <- function(x) {
 #' @include alignpatch-ggplot2.R
 PatchAlignMark <- ggproto(
     "PatchAlignMark", PatchGgplot,
-    patch_gtable = function(self, theme, guides, plot = self$plot) {
-        ans <- ggproto_parent(PatchGgplot, self)$patch_gtable(plot = plot)
+    patch_gtable = function(self, theme, guides, tagger) {
+        plot <- self$plot
+        ans <- ggproto_parent(PatchGgplot, self)$patch_gtable(
+            theme = theme, guides = guides, tagger = tagger
+        )
         # re-define the draw method, we assign new class
         ans <- add_class(ans, "ggalignMarkGtable")
-        ans$ggalign_link_data <- .subset2(plot, "ggalign_link_data")
+        ans$ggalign_link_data <- plot$ggalign_link_data
         ans
     },
     add_plot = function(self, gt, plot, t, l, b, r, name, z = 2L) {
@@ -491,16 +523,14 @@ makeContent.ggalignMarkGtable <- function(x) {
         )
         nms <- names(link_index)
         link_panels <- vec_rep_each(names(full_breaks), list_sizes(full_breaks))
+        link_panels <- factor(link_panels, names(full_breaks))
         coords[[link]] <- lapply(seq_along(link_index), function(i) {
             l_index <- .subset2(link_index, i)
             if (is.null(l_index)) return(NULL) # styler: off
             d_index <- .subset2(data_index, i)
             link <- vec_slice(link_coord, l_index)
             link$link_id <- nms[i]
-            link$link_panel <- reorder(
-                vec_slice(link_panels, l_index), l_index,
-                order = FALSE
-            )
+            link$link_panel <- vec_slice(link_panels, l_index)
             link$link_index <- l_index
             link$.hand <- hand
             link$.index <- d_index
