@@ -188,6 +188,7 @@ range_link <- function(point1, point2) {
 is_range_link <- function(x) inherits(x, "ggalign_range_link")
 
 ########################################################
+# nocov start
 new_pair_link <- function(hand1 = NULL, hand2 = NULL,
                           ..., class = character()) {
     structure(
@@ -332,6 +333,7 @@ vec_ptype2.ggalign_pair_link.list <- function(x, y, ...) {
 vec_ptype2.list.ggalign_pair_link <- function(x, y, ...) {
     y
 }
+# nocov end
 
 #############################################################
 #' @export
@@ -438,6 +440,7 @@ as_obs_link.list <- function(x, ..., arg = caller_arg(x),
 #' @export
 as_obs_link.ggalign_range_link <- as_obs_link.NULL
 
+# nocov start
 #' @export
 as_obs_link.default <- function(x, ..., arg = caller_arg(x),
                                 call = caller_env()) {
@@ -453,7 +456,7 @@ print.ggalign_range_link <- function(x, ...) {
     cat(deparse_link(x))
     invisible(x)
 }
-
+# nocov end
 ###########################################################
 #' @return A single string
 #' @noRd
@@ -552,11 +555,11 @@ deparse_link2.list <- function(x, trunc = 3L, head = trunc - 1L,
 }
 
 ###################################################
-make_links_data <- function(links, design1, design2,
+make_links_data <- function(links, domain1, domain2,
                             labels1, labels2) {
     link_index_list <- lapply(
         links, make_pair_link_index,
-        design1 = design1, design2 = design2,
+        domain1 = domain1, domain2 = domain2,
         labels1 = labels1, labels2 = labels2,
         handle_missing = attr(links, "handle_missing")
     )
@@ -575,19 +578,19 @@ make_links_data <- function(links, design1, design2,
     link_index_list
 }
 
-make_pair_link_index <- function(pair_link, design1, design2,
+make_pair_link_index <- function(pair_link, domain1, domain2,
                                  labels1, labels2, handle_missing) {
     input1 <- .subset2(pair_link, 1L)
     input2 <- .subset2(pair_link, 2L)
 
     # make the data
     hand1 <- make_link_index(input1,
-        design = design1, labels = labels1,
+        domain = domain1, labels = labels1,
         other = input2, data_index = !inherits(pair_link, "AsIs"),
         handle_missing = handle_missing
     )
     hand2 <- make_link_index(input2,
-        design = design2, labels = labels2,
+        domain = domain2, labels = labels2,
         other = input1, data_index = !inherits(pair_link, "AsIs"),
         handle_missing = handle_missing
     )
@@ -597,14 +600,14 @@ make_pair_link_index <- function(pair_link, design1, design2,
     list(hand1 = hand1, hand2 = hand2)
 }
 
-make_link_index <- function(link, design, labels, other, data_index,
+make_link_index <- function(link, domain, labels, other, data_index,
                             handle_missing, arg = caller_arg(link),
                             call = caller_call()) {
     link <- link_to_location(
         link,
-        n = .subset2(design, "nobs"),
+        n = prop(domain, "nobs"),
         labels = labels,
-        index = .subset2(design, "index"),
+        index = prop(domain, "index"),
         other = other,
         data_index = data_index,
         handle_missing = handle_missing,
@@ -651,6 +654,7 @@ link_to_location.integer <- function(x, ..., n, index, data_index,
     if (isTRUE(data_index)) match(ans, index) else ans
 }
 
+# nocov start
 #' @export
 link_to_location.ggalign_range_link <- function(x, ..., arg = caller_arg(x),
                                                 call = caller_call()) {
@@ -678,6 +682,7 @@ link_to_location.list <- function(x, ...) {
 link_to_location.waiver <- function(x, ..., other) {
     link_to_location(other %|w|% NULL, ...)
 }
+# nocov end
 
 #' @export
 link_to_location.NULL <- function(x, ...) NULL
