@@ -5,6 +5,22 @@ assert_gp <- function(gp, arg = caller_arg(gp), call = caller_call()) {
     assert_s3_class(gp, "gpar", arg = arg, call = call)
 }
 
+assert_genomic_data <- function(data, arg = caller_arg(data),
+                                call = caller_env()) {
+    if (ncol(data) < 3L) {
+        cli_abort("{.arg {arg}} must have at least 3 columns: chromosome, start, and end", call = call)
+    }
+    if (anyNA(data[[1L]]) || anyNA(data[[2L]]) || anyNA(data[[3L]])) {
+        cli_abort("Columns 1, 2, and 3 of {.arg {arg}} must not contain missing values", call = call)
+    }
+    if (!is.numeric(data[[2L]]) || !is.numeric(data[[3L]])) {
+        cli_abort("Columns 2 and 3 of {.arg {arg}} must be numeric (start and end positions)", call = call)
+    }
+    if (any(data[[2L]] > data[[3L]])) {
+        cli_abort("Column 2 (start) must not be greater than column 3 (end) in any row of {.arg {arg}}", call = call)
+    }
+}
+
 #' @importFrom rlang caller_arg caller_call
 assert_mapping <- function(mapping, arg = caller_arg(mapping),
                            call = caller_call()) {
@@ -103,38 +119,9 @@ check_stack_sizes <- function(sizes, arg = caller_arg(sizes),
             call = call
         )
     }
-    if (!is.unit(sizes)) sizes <- unit(sizes, "null")
     sizes
 }
 
-#' @importFrom rlang arg_match0
-check_direction <- function(direction, arg = caller_arg(direction),
-                            call = caller_call()) {
-    direction <- arg_match0(direction, c("h", "v"),
-        arg_nm = arg, error_call = call
-    )
-    switch(direction, h = "horizontal", v = "vertical") # styler: off
-}
-
-assert_limits <- function(limits, allow_null = TRUE, arg = caller_arg(limits),
-                          call = caller_call()) {
-    if (is.null(limits) && allow_null) {
-        return(invisible(NULL))
-    }
-    if (!inherits(limits, "continuous_limits")) {
-        cli_abort(
-            "{.arg {arg}} must be specified with {.fn continuous_limits}",
-            call = call
-        )
-    }
-    if (rlang::is_named(limits)) {
-        cli_abort(
-            "{.arg {arg}} shouldn't be created with {.arg x}/{.arg y} argument in {.fn continuous_limits}",
-            call = call
-        )
-    }
-}
-
 #' @importFrom grid is.unit
 check_size <- function(size, arg = caller_arg(size), call = caller_call()) {
     if (!is_scalar(size) &&
@@ -144,10 +131,32 @@ check_size <- function(size, arg = caller_arg(size), call = caller_call()) {
             call = call
         )
     }
-    if (!is.unit(size)) size <- unit(size, "null")
     size
 }
 
+#' @importFrom rlang arg_match0
+check_direction <- function(direction, arg = caller_arg(direction),
+                            call = caller_call()) {
+    direction <- arg_match0(direction, c("h", "v"),
+        arg_nm = arg, error_call = call
+    )
+    switch(direction, h = "horizontal", v = "vertical") # styler: off
+}
+
+#' @importFrom rlang is_named
+assert_limits <- function(limits, allow_null = TRUE, arg = caller_arg(limits),
+                          call = caller_call()) {
+    if (is.null(limits) && allow_null) {
+        return(invisible(NULL))
+    }
+    if (!is_continuous_domain(limits)) {
+        cli_abort(
+            "{.arg {arg}} must be specified with {.fn continuous_limits}",
+            call = call
+        )
+    }
+}
+
 check_scheme_data <- function(data, arg = caller_arg(data),
                               call = caller_call()) {
     if (!is.waive(data) && !is.null(data) &&
@@ -162,7 +171,7 @@ check_scheme_data <- function(data, arg = caller_arg(data),
 
 check_stack_context <- function(what, arg = caller_arg(what),
                                 call = caller_call()) {
-    if (is.null(what)) return(what) # styler: off
+    if (is.null(what)) return(NA_integer_) # styler: off
     if (.rlang_check_number(what, allow_decimal = FALSE, min = 1) != 0L &&
         !is_string(what)) {
         cli_abort(
@@ -183,21 +192,12 @@ check_order <- function(order, arg = caller_arg(order), call = caller_call()) {
     }
 }
 
-assert_align <- function(x, arg = caller_arg(x), call = caller_call()) {
-    if (!inherits(x, "scheme_align")) {
-        cli_abort(
-            "{.arg {arg}} must be created by {.fn scheme_align}",
-            call = call
-        )
-    }
-}
-
 assert_active <- function(x, allow_null = TRUE,
                           arg = caller_arg(x), call = caller_call()) {
     if (is.null(x) && allow_null) {
         return(invisible(NULL))
     }
-    if (!inherits(x, "ggalign_active")) {
+    if (!is_active(x)) {
         cli_abort(
             "{.arg {arg}} must be created by {.fn active}",
             call = call
