@@ -1,3 +1,29 @@
+with_empty_dev <- function(plot, ...) {
+    grDevices::pdf(NULL)
+    print(plot, ...)
+    dev.off()
+}
+
+test_that("print.alignpatches sets last plot and draws grid", {
+    p <- align_plots()
+    with_empty_dev(p)
+    expect_identical(ggplot2::last_plot(), p)
+})
+
+test_that("print.alignpatches seeks or pushes viewport when vp is provided", {
+    p <- align_plots()
+
+    # Errors if vp is character and newpage=TRUE
+    expect_snapshot_error(with_empty_dev(p, newpage = TRUE, vp = "some_vp"))
+
+    # Errors if vp does not exist as a viewport
+    expect_snapshot_error(with_empty_dev(p, newpage = FALSE, vp = "panel-1-1"))
+
+    # Test with viewport object
+    vp_obj <- viewport()
+    expect_silent(with_empty_dev(p, newpage = TRUE, vp = vp_obj))
+})
+
 test_that("The grid can be controlled", {
     p1 <- ggplot(mtcars) +
         geom_point(aes(mpg, disp)) +
@@ -71,13 +97,11 @@ test_that("The grid can be controlled", {
                 p3 + theme(plot.background = element_blank()),
                 p4 + theme(plot.background = element_blank())
             ) +
-                layout_annotation(
-                    theme = theme(
-                        panel.border = element_rect(colour = "blue"),
-                        plot.background = element_rect(
-                            fill = "yellow", color = "black",
-                            linewidth = unit(1, "cm")
-                        )
+                layout_theme(
+                    panel.border = element_rect(colour = "blue"),
+                    plot.background = element_rect(
+                        fill = "yellow", color = "black",
+                        linewidth = unit(1, "cm")
                     )
                 )
         ) +
@@ -85,18 +109,55 @@ test_that("The grid can be controlled", {
                 title = "I'm layout title",
                 subtitle = "I'm layout subtitle",
                 caption = "I'm layout caption"
-            ) + layout_annotation(
-                theme = theme(
-                    panel.border = element_rect(colour = "red"),
-                    plot.background = element_rect(
-                        fill = "green", color = "black",
-                        linewidth = unit(1, "cm")
-                    )
+            ) + layout_theme(
+                panel.border = element_rect(colour = "red"),
+                plot.background = element_rect(
+                    fill = "green", color = "black",
+                    linewidth = unit(1, "cm")
                 )
             )
     })
 })
 
+test_that("accept patchwork", {
+    testthat::skip_if_not_installed("patchwork")
+    p1 <- ggplot(mtcars) +
+        geom_point(aes(mpg, disp)) +
+        ggtitle("Plot 1")
+
+    p2 <- ggplot(mtcars) +
+        geom_boxplot(aes(gear, disp, group = gear)) +
+        ggtitle("Plot 2")
+
+    p3 <- ggplot(mtcars) +
+        geom_point(aes(hp, wt, colour = mpg)) +
+        ggtitle("Plot 3")
+
+    p4 <- ggplot(mtcars) +
+        geom_bar(aes(gear)) +
+        facet_wrap(~cyl) +
+        ggtitle("Plot 4")
+    expect_doppelganger("align_plots() add patchwork wrap_plots", {
+        align_plots(patchwork::wrap_plots(p1, p2), p3, p4)
+    })
+    expect_doppelganger("align_plots() add patchwork spacer", {
+        align_plots(patchwork::plot_spacer(), p2, p3, p4)
+    })
+    p1 <- ggplot(mtcars) +
+        geom_bar(aes(y = factor(gear), fill = factor(gear))) +
+        scale_y_discrete(
+            "",
+            labels = c(
+                "3 gears are often enough",
+                "But, you know, 4 is a nice number",
+                "I would def go with 5 gears in a modern car"
+            )
+        )
+    expect_doppelganger("align_plots() add patchwork free", {
+        align_plots(patchwork::free(p1, side = "l"), p2, p3, p4)
+    })
+})
+
 test_that("`ggsave()` works well", {
     p1 <- ggplot(mtcars) +
         geom_point(aes(mpg, disp)) +
@@ -436,3 +497,138 @@ test_that("`free_guide()` works well", {
         )
     )
 })
+
+test_that("`layout_tags()` works well", {
+    p1 <- ggplot(mtcars) +
+        geom_point(aes(mpg, disp))
+    p2 <- ggplot(mtcars) +
+        geom_boxplot(aes(gear, disp, group = gear))
+    p3 <- ggplot(mtcars) +
+        geom_bar(aes(gear)) +
+        facet_wrap(~cyl)
+
+    # Add tags to plots
+    expect_doppelganger(
+        "layout_tags, inherits tags by nested layout",
+        align_plots(p1, align_plots(p2, p3), ncol = 1) + layout_tags("A")
+    )
+
+    expect_doppelganger(
+        "layout_tags, disable nested inner tagging",
+        align_plots(p1, align_plots(p2, p3) + layout_tags(NULL), ncol = 1) +
+            layout_tags("A")
+    )
+
+    # Add multilevel tagging to nested layouts
+    expect_doppelganger(
+        "layout_tags, nested layout with multilevel tagging",
+        align_plots(
+            p1,
+            align_plots(p2, p3) + layout_tags(1),
+            ncol = 1
+        ) +
+            layout_tags("A")
+    )
+
+    # Use a custom tag sequence (mixed with a standard one)
+    expect_doppelganger(
+        "layout_tags, custom tag sequence",
+        align_plots(
+            p1,
+            align_plots(p2, p3) + layout_tags(1),
+            ncol = 1
+        ) +
+            layout_tags(c("&", "%"))
+    )
+
+    expect_snapshot_warning(
+        with_empty_dev(align_plots(p1, p2, p3, nrow = 1) +
+            layout_tags(c("&", "%")))
+    )
+    expect_doppelganger(
+        "layout_tags, recycled the tags",
+        align_plots(
+            p1,
+            align_plots(p2, p3) + layout_tags(1),
+            ncol = 1
+        ) +
+            layout_tags("A")
+    )
+    expect_doppelganger(
+        "layout_tags, location = plot",
+        align_plots(
+            p1,
+            align_plots(p2, p3) + layout_tags(1),
+            ncol = 1
+        ) +
+            layout_tags("A") +
+            layout_theme(plot.tag.location = "plot")
+    )
+    expect_snapshot_error(
+        with_empty_dev(align_plots(p1, p2, p3, nrow = 1) +
+            layout_tags("A") +
+            layout_theme(
+                plot.tag.location = "margin",
+                plot.tag.position = c(0.5, 0.5)
+            ))
+    )
+    expect_snapshot_error(
+        with_empty_dev(align_plots(p1, p2, p3, nrow = 1) +
+            layout_tags("A") +
+            layout_theme(plot.tag.position = c(0.5, 0.5, 0.5)))
+    )
+
+    expect_doppelganger(
+        "layout_tags, location = panel",
+        align_plots(
+            p1,
+            align_plots(p2, p3) + layout_tags(1),
+            ncol = 1
+        ) +
+            layout_tags("A") +
+            layout_theme(plot.tag.location = "panel")
+    )
+
+    expect_doppelganger(
+        "layout_tags, use plot theme",
+        align_plots(
+            p1,
+            align_plots(p2, p3) + layout_tags(1),
+            ncol = 1
+        ) +
+            layout_tags("A") &
+            theme(plot.tag.location = "panel")
+    )
+
+    expect_doppelganger(
+        "layout_tags, location = margin",
+        align_plots(
+            p1,
+            align_plots(p2, p3) + layout_tags(1),
+            ncol = 1
+        ) +
+            layout_tags("A") +
+            layout_theme(plot.tag.location = "margin")
+    )
+
+    # make a matrix for the heatmap
+    set.seed(123)
+    mat <- matrix(
+        rnorm(90, mean = 0, sd = 2),
+        nrow = 9, ncol = 10,
+        dimnames = list(paste0("G", 1:9), paste0("S", 1:10))
+    )
+    final <- align_plots(
+        align_plots(p1, p2, p3, nrow = 1),
+        ggheatmap(mat),
+        ncol = 1
+    )
+    expect_doppelganger("layout_tags, Layout object, layout_theme", {
+        final + layout_tags("A") +
+            layout_theme(plot.tag = element_text(size = 26, color = "red"))
+    })
+    expect_doppelganger("layout_tags, Layout object, theme", {
+        final + layout_tags("A") &
+            theme(plot.tag = element_text(size = 26, color = "red"))
+    })
+})
