@@ -84,7 +84,7 @@ test_that("`geom_subtile()` works well", {
     )
 })
 
-test_that("geom_pie works well", {
+test_that("`geom_pie()` works well", {
     expect_doppelganger(
         "geom_pie_clockwise",
         ggplot(data.frame(x = 1:10, y = 1:10, value = 1:10 / sum(1:10))) +
@@ -102,6 +102,42 @@ test_that("geom_pie works well", {
     )
 })
 
+test_that("`geom_tile3d()` works well", {
+    set.seed(123)
+    small_mat <- matrix(rnorm(72), nrow = 9)
+    rownames(small_mat) <- paste0("row", seq_len(nrow(small_mat)))
+    colnames(small_mat) <- paste0("column", seq_len(ncol(small_mat)))
+
+    expect_doppelganger(
+        "geom_tile3d",
+        ggplot2::ggplot(fortify_data_frame(small_mat)) +
+            geom_tile3d(aes(
+                .column_index, .row_index,
+                fill = value, z = value,
+                width = 0.8, height = 0.8
+            )) +
+            scale_z_continuous()
+    )
+})
+
+test_that("`geom_rect3d()` works well", {
+    set.seed(123)
+    small_mat <- matrix(rnorm(72), nrow = 9)
+    rownames(small_mat) <- paste0("row", seq_len(nrow(small_mat)))
+    colnames(small_mat) <- paste0("column", seq_len(ncol(small_mat)))
+
+    expect_doppelganger(
+        "geom_rect3d",
+        ggplot2::ggplot(fortify_data_frame(small_mat)) +
+            geom_rect3d(aes(
+                .column_index, .row_index,
+                fill = value, z = value,
+                width = 0.8, height = 0.8
+            )) +
+            scale_z_continuous()
+    )
+})
+
 test_that("`geom_gshape()` works well", {
     library(grid)
     expect_snapshot_error(ggplot2::ggsave(
@@ -192,17 +228,66 @@ test_that("`coord_circle()` works well", {
     )
 })
 
+test_that("`no_expansion()` works well", {
+    expect_doppelganger(
+        "no_expansion()",
+        ggplot(mtcars, aes(disp, mpg)) +
+            geom_point() +
+            no_expansion()
+    )
+})
+
 test_that("`facet_sector()` works well", {
     expect_doppelganger(
-        "facet_sector() default",
+        "facet_sector(), default",
         ggplot(mtcars, aes(disp, mpg)) +
             geom_point() +
             facet_sector(vars(cyl))
     )
     expect_doppelganger(
-        "facet_sector() sector_spacing rel()",
+        "facet_sector(), sector_spacing rel()",
         ggplot(mtcars, aes(disp, mpg)) +
             geom_point() +
             facet_sector(vars(cyl), sector_spacing = rel(0.01))
     )
+    expect_doppelganger(
+        "facet_sector(), multiple sector_spacing",
+        ggplot(mtcars, aes(disp, mpg)) +
+            geom_point() +
+            facet_sector(vars(cyl), sector_spacing = c(pi / 180, pi / 180 * 5))
+    )
+})
+
+test_that("`geom_draw()` works well", {
+    text <- grid::textGrob(
+        "ggdraw",
+        x = c(0, 0, 0.5, 1, 1),
+        y = c(0, 1, 0.5, 0, 1),
+        hjust = c(0, 0, 0.5, 1, 1),
+        vjust = c(0, 1, 0.5, 0, 1)
+    )
+    expect_doppelganger(
+        "geom_draw(), grob",
+        ggplot(data.frame(x = 1, y = 2)) +
+            geom_draw(text)
+    )
+})
+
+test_that("`geom_magick()` works well", {
+    skip_if_not_installed("magick")
+    set.seed(123)
+    d <- data.frame(
+        x = rnorm(10),
+        y = rnorm(10),
+        image = "https://jeroenooms.github.io/images/frink.png",
+        fill = sample(c("A", "B", "C", "D"), 10, replace = TRUE),
+        alpha = rnorm(10, mean = 0.5, sd = 0.1)
+    )
+    d$alpha <- pmax(pmin(d$alpha, 1), 0)
+
+    expect_doppelganger(
+        "geom_magick()",
+        ggplot(d, aes(x, y)) +
+            geom_magick(aes(image = image, fill = fill, alpha = alpha))
+    )
 })
