@@ -1,9 +1,3 @@
-test_that("ChainLayout class creation", {
-    layout <- new("ChainLayout")
-    expect_s4_class(layout, "ChainLayout")
-    expect_true(is.list(layout@plot_list))
-})
-
 test_that("is_layout_discrete function", {
     expect_true(is_layout_discrete(stack_discrete("h")))
     expect_true(is_layout_discrete(stack_discrete("v")))
@@ -16,18 +10,6 @@ test_that("is_layout_continuous function", {
     expect_true(is_layout_continuous(stack_continuous("v")))
 })
 
-test_that("`chain_layout_add()` with layout_title", {
-    layout <- new("ChainLayout")
-    layout <- chain_layout_add(layout_title("my title"), layout, "title")
-    expect_equal(layout@titles, list(title = "my title"))
-})
-
-test_that("`chain_layout_add()` function with NULL", {
-    old <- new("ChainLayout", plot_list = list())
-    new <- chain_layout_add(NULL, old, "NULL")
-    expect_identical(old, new)
-})
-
 test_that("`chain_layout_add()` function with `CraftBox`", {
     set.seed(1L)
     small_mat <- matrix(rnorm(72), nrow = 8)
@@ -45,19 +27,16 @@ test_that("`chain_layout_add()` function with `CraftBox`", {
     stack <- stack_discrete("h", small_mat) +
         align_dendro()
     expect_identical(
-        stack@design$index,
+        stack@domain@index,
         order2(ggalign_stat(stack, 1L))
     )
     # layout `panel` is updated correctly
     stack <- stack_discrete("h", small_mat) + align_dendro(k = 3L)
+    expect_null(.subset2(stack@box_list, 1L)@craftsman$panel)
     expect_identical(
-        stack@design$panel,
-        .subset2(stack@plot_list, 1L)@craftsman$panel
-    )
-    expect_identical(
-        stack@design$index,
+        stack@domain@index,
         reorder_index(
-            .subset2(stack@plot_list, 1L)@craftsman$panel,
+            stack@domain@panel,
             order2(ggalign_stat(stack, 1L))
         )
     )
@@ -70,26 +49,23 @@ test_that("`chain_layout_add()` function with `CraftBox`", {
     stack <- stack_discrete("v", small_mat) +
         align_dendro()
     expect_identical(
-        stack@design$index,
+        stack@domain@index,
         order2(ggalign_stat(stack, 1L))
     )
     # layout `panel` is updated correctly
     stack <- stack_discrete("v", small_mat) + align_dendro(k = 3L)
+    expect_null(.subset2(stack@box_list, 1L)@craftsman$panel)
     expect_identical(
-        stack@design$panel,
-        .subset2(stack@plot_list, 1L)@craftsman$panel
-    )
-    expect_identical(
-        stack@design$index,
+        stack@domain@index,
         reorder_index(
-            .subset2(stack@plot_list, 1L)@craftsman$panel,
+            stack@domain@panel,
             order2(ggalign_stat(stack, 1L))
         )
     )
 })
 
 ###################################################################
-testthat::test_that("`chain_layout_add()` function with QuadLayout", {
+test_that("`chain_layout_add()` function with QuadLayout", {
     set.seed(1L)
     small_mat <- matrix(rnorm(72), nrow = 8)
     rownames(small_mat) <- paste0("row", seq_len(nrow(small_mat)))
@@ -99,13 +75,13 @@ testthat::test_that("`chain_layout_add()` function with QuadLayout", {
     expect_snapshot_error(stack_discrete("h") + quad_discrete())
     expect_snapshot_error(stack_discrete("h") + quad_alignv())
     expect_snapshot_error(stack_discrete("h") + quad_continuous())
-    # incompatible design
+    # incompatible domain
     expect_snapshot_error(stack_discrete("h", small_mat) + quad_alignv())
 
     expect_snapshot_error(stack_discrete("v") + quad_discrete())
     expect_snapshot_error(stack_discrete("v") + quad_alignv())
     expect_snapshot_error(stack_discrete("v") + quad_continuous())
-    # incompatible design
+    # incompatible domain
     expect_snapshot_error(stack_discrete("v", small_mat) + quad_alignh())
 
     # stack_continuous()
@@ -119,48 +95,48 @@ testthat::test_that("`chain_layout_add()` function with QuadLayout", {
     expect_snapshot_error(stack_continuous("v", mtcars) +
         quad_alignh())
 
-    # `stack_discrete()` update layout design correctly
+    # `stack_discrete()` update layout domain correctly
     stack <- stack_discrete("h", small_mat) + quad_alignh()
     expect_identical(
-        stack@design,
-        .subset2(stack@plot_list, 1L)@horizontal
+        stack@domain,
+        .subset2(stack@box_list, 1L)@horizontal
     )
     stack <- stack_discrete("h") +
         (quad_alignh(small_mat) + anno_left() + align_dendro())
     expect_identical(
-        stack@design,
-        .subset2(stack@plot_list, 1L)@horizontal
+        stack@domain,
+        .subset2(stack@box_list, 1L)@horizontal
     )
     stack <- stack_discrete("h") +
         quad_alignh(small_mat) +
         (quad_alignh(small_mat) + anno_left() + align_dendro())
     expect_identical(
-        stack@design,
-        .subset2(stack@plot_list, 1L)@horizontal
+        stack@domain,
+        .subset2(stack@box_list, 1L)@horizontal
     )
     expect_identical(
-        stack@design,
-        .subset2(stack@plot_list, 2L)@horizontal
+        stack@domain,
+        .subset2(stack@box_list, 2L)@horizontal
     )
 
     stack <- stack_discrete("h") +
         (quad_alignh(small_mat) +
             anno_left() + align_dendro(k = 3L))
     expect_identical(
-        stack@design,
-        .subset2(stack@plot_list, 1L)@horizontal
+        stack@domain,
+        .subset2(stack@box_list, 1L)@horizontal
     )
     stack <- stack_discrete("h") +
         quad_alignh(small_mat) +
         (quad_alignh(small_mat) +
             anno_left() + align_dendro(k = 3L))
     expect_identical(
-        stack@design,
-        .subset2(stack@plot_list, 1L)@horizontal
+        stack@domain,
+        .subset2(stack@box_list, 1L)@horizontal
     )
     expect_identical(
-        stack@design,
-        .subset2(stack@plot_list, 2L)@horizontal
+        stack@domain,
+        .subset2(stack@box_list, 2L)@horizontal
     )
 
     stack <- stack_discrete("h", small_mat) +
@@ -169,12 +145,12 @@ testthat::test_that("`chain_layout_add()` function with QuadLayout", {
         stack_discrete("h", small_mat) +
         align_dendro()
     expect_identical(
-        stack@design,
-        .subset2(stack@plot_list, 1L)@horizontal
+        stack@domain,
+        .subset2(stack@box_list, 1L)@horizontal
     )
     expect_identical(
-        stack@design,
-        .subset2(stack@plot_list, 1L)@left@design
+        stack@domain,
+        .subset2(stack@box_list, 1L)@left@domain
     )
     expect_snapshot_error(stack_discrete("h", small_mat) +
         quad_alignh() +
@@ -188,43 +164,43 @@ testthat::test_that("`chain_layout_add()` function with QuadLayout", {
     # `stack_alignv()` update layout coords correctly
     stack <- stack_alignv(small_mat) + quad_alignv()
     expect_identical(
-        stack@design,
-        .subset2(stack@plot_list, 1L)@vertical
+        stack@domain,
+        .subset2(stack@box_list, 1L)@vertical
     )
     stack <- stack_alignv() +
         (quad_alignv(small_mat) + anno_top() + align_dendro())
     expect_identical(
-        stack@design,
-        .subset2(stack@plot_list, 1L)@vertical
+        stack@domain,
+        .subset2(stack@box_list, 1L)@vertical
     )
     stack <- stack_alignv() +
         quad_alignv(small_mat) +
         (quad_alignv(small_mat) + anno_top() + align_dendro())
     expect_identical(
-        stack@design,
-        .subset2(stack@plot_list, 1L)@vertical
+        stack@domain,
+        .subset2(stack@box_list, 1L)@vertical
     )
     expect_identical(
-        stack@design,
-        .subset2(stack@plot_list, 2L)@vertical
+        stack@domain,
+        .subset2(stack@box_list, 2L)@vertical
     )
 
     stack <- stack_alignv() +
         (quad_alignv(small_mat) + anno_top() + align_dendro(k = 3L))
     expect_identical(
-        stack@design,
-        .subset2(stack@plot_list, 1L)@vertical
+        stack@domain,
+        .subset2(stack@box_list, 1L)@vertical
     )
     stack <- stack_alignv() +
         quad_alignv(small_mat) +
         (quad_alignv(small_mat) + anno_top() + align_dendro(k = 3L))
     expect_identical(
-        stack@design,
-        .subset2(stack@plot_list, 1L)@vertical
+        stack@domain,
+        .subset2(stack@box_list, 1L)@vertical
     )
     expect_identical(
-        stack@design,
-        .subset2(stack@plot_list, 2L)@vertical
+        stack@domain,
+        .subset2(stack@box_list, 2L)@vertical
     )
 
     stack <- stack_alignv(small_mat) +
@@ -233,12 +209,12 @@ testthat::test_that("`chain_layout_add()` function with QuadLayout", {
         stack_alignv(small_mat) +
         align_dendro()
     expect_identical(
-        stack@design,
-        .subset2(stack@plot_list, 1L)@vertical
+        stack@domain,
+        .subset2(stack@box_list, 1L)@vertical
     )
     expect_identical(
-        stack@design,
-        .subset2(stack@plot_list, 1L)@top@design
+        stack@domain,
+        .subset2(stack@box_list, 1L)@top@domain
     )
     expect_snapshot_error(stack_alignv(small_mat) +
         quad_alignv() +
@@ -250,34 +226,20 @@ testthat::test_that("`chain_layout_add()` function with QuadLayout", {
             stack_crossv()))
 })
 
-test_that("`chain_layout_add()` function with stack_switch", {
-    set.seed(1L)
-    small_mat <- matrix(rnorm(72), nrow = 8)
-    # change parameters for stack self
-    p <- stack_alignh(small_mat)
-    p2 <- p + stack_active(sizes = unit(1, "cm")) -
-        scheme_align(guides = "tlbr", free_labs = "tlbr")
-    expect_identical(p2@sizes, unit(1, "cm"))
-    schemes <- p2@schemes
-    expect_identical(schemes$scheme_align$guides, "tlbr")
-    expect_identical(schemes$scheme_align$free_labs, "tlbr")
-    expect_identical(schemes$scheme_data, new_scheme_data(NULL))
-})
-
-test_that("`chain_layout_add()` function with ggalign_with_quad", {
+test_that("`chain_layout_add()` function with quad_scope", {
     set.seed(1L)
     small_mat <- matrix(rnorm(72), nrow = 8)
     rownames(small_mat) <- paste0("row", seq_len(nrow(small_mat)))
     colnames(small_mat) <- paste0("column", seq_len(ncol(small_mat)))
     expect_snapshot_error(stack_discrete("v", small_mat) +
         align_dendro() +
-        with_quad(geom_point()))
+        quad_scope(geom_point()))
 })
 
 test_that("`chain_layout_add()` function with CrossLayout", {
 })
 
-test_that("`chain_layout_add()` function with layout_annotation", {
+test_that("`chain_layout_add()` function with layout_theme", {
 
 })
 
